'''Apport package hook for Project Neon.

Copyright 2010-2011 Philip Muskovac <yofel@gmx.net>

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
'''

import os
import gzip
import apport

def add_info(report, ui):

    ui.information("Please note that you should only file bugs about the Project-Neon packaging on Launchpad. Please file bugs in the applications in their respective bug tracker.")
    if not apport.packaging.is_distro_package(report['Package'].split()[0]):
        report['ThirdParty'] = 'True'
        report['CrashDB'] = 'project_neon'

    # add the package name to the title by default
    report['Title'] = '[' + report['Package'].split(' ')[0] + ']'

    n_session = False
    # check if we're running Neon
    try:
        if os.environ['NEON_SESSION'] == 'true':
            n_session = True
            report['NEON_SESSION'] = 'true'
    except:
        pass

    # attach .xsession-errors if we're running neon (compressed)
    # and user agrees - FIXME: DOESN'T WORK WITH SUDO
    if n_session and os.getuid() != 0:
        if ui.yesno("Attach your ~/.xsession-errors to the bug report? This will help with debugging, but might have private information in it."):
            f_in = open(os.path.expanduser('~/.xsession-errors'), 'rb')
            f_out = gzip.open('/tmp/xe.gz', 'wb')
            f_out.writelines(f_in)
            f_out.close()
            f_in.close()
            attach_file(report, '/tmp/xe.gz', "Xsession-errors")
            os.remove('/tmp/xe.gz')

    # attach various X related information for kde-workspace
    if report['SourcePackage'] == 'project-neon-kde-workspace':
        attach_file(report, "/var/log/kdm.log", "kdm.log")
        attach_file(report, "/var/log/Xorg.0.log", "Xorg.0.log")
        attach_file(report, "/var/log/Xorg.0.log.old", "Xorg.0.log.old")

        f = open("/etc/X11/default-display-manager")
        report['default-display-manager'] = f.readline()
        f.close()
